@@ -1,4 +1,5 @@
-map.new = function(x, legendRight=FALSE, buffer=0, mar=c(0,0,0,0), ...) {
+map.new = function(x, legendRight=FALSE, buffer=0,
+                   mar=c(0,0,0,0), ...) {
 	
 	if(!is.null(attributes(x)$ellipse)) {
 		ellipse = x = attributes(x)$ellipse
@@ -23,11 +24,19 @@ map.new = function(x, legendRight=FALSE, buffer=0, mar=c(0,0,0,0), ...) {
 
 	ldots = list(...)
 	ldots$mar = mar
-	if(!length(ldots$bty) & mar[4]>0 ) ldots$bty='l'
+	if(!length(ldots$bty)) {
+		if( mar[4]>0 ) {
+			ldots$bty='l'
+		} else {
+			ldots$bty='n'			
+		}
+	}
 	if(!length(ldots$xpd)) ldots$xpd=FALSE
 	if(!length(ldots$axes)) ldots$axes=TRUE
 	if(!length(ldots$xaxs)) ldots$xaxs = 'i'
 	if(!length(ldots$yaxs)) ldots$yaxs = 'i'
+	if(!length(ldots$xaxt)) ldots$xaxt = 'n'
+	if(!length(ldots$yaxt)) ldots$yaxt = 'n'
 	
   	do.call(par, ldots[setdiff(names(ldots),'axes')]) #(mar=mar, xaxs='i',yaxs='i',xpd=FALSE, ...)
   
