@@ -47,7 +47,7 @@ if(all(unlist(mapply(requireNamespace, package=Spackages, MoreArgs=list(quietly=
 	map.new(xTcrop, buffer=1000*1000)
  plot(attributes(myCrsO)$ellipse, add=TRUE, col='lightBlue', border='blue')
 	plot(xTcrop,add=TRUE, col='grey')
-	plot(xTcrop[DcountryT,], col='red', add=TRUE)
+	plot(xTcrop[DcountryT,], col='red', lty=0, add=TRUE)
 	
 	gridlinesWrap(myCrsO, lty=2, col='orange')
 	
@@ -56,8 +56,9 @@ if(all(unlist(mapply(requireNamespace, package=Spackages, MoreArgs=list(quietly=
 	Dcountry  = grep(country, wrld_simpl$NAME)
 	x=wrld_simpl[Dcountry,]
 	
-	myCrsMoll = moll(x, angle=100)
+	myCrsMoll = moll(x, angle=100, flip= 'nwu' )
 	
+	plot(attributes(myCrsMoll)$ellipse)
 	
 	plot(wrld_simpl)
 	plot(attributes(myCrsMoll)$crop, border='red', col='#0000FF10', add=TRUE)
@@ -66,11 +67,35 @@ if(all(unlist(mapply(requireNamespace, package=Spackages, MoreArgs=list(quietly=
 	DcountryT  = grep(country, xTcrop$NAME)
 	
 	map.new(xTcrop)
-	plot(attributes(myCrsO)$ellipse, add=TRUE, col='lightBlue', border='blue')
+	plot(attributes(myCrsMoll)$ellipse, add=TRUE, col='lightBlue', border='blue')
 	plot(xTcrop,add=TRUE, col='grey')
 	plot(xTcrop[DcountryT,], col='green', add=TRUE)
 	
 	gridlinesWrap(crs=xTcrop, lty=2, col='red')
 
+	
+	
+	country='Iceland'
+	Dcountry  = grep(country, wrld_simpl$NAME)
+	x=wrld_simpl[Dcountry,]
+	
+	myCrsMoll = moll(x,  angle=0, flip= 'nwu' )
+	
+	plot(attributes(myCrsMoll)$ellipse)
+	
+	plot(wrld_simpl)
+	plot(attributes(myCrsMoll)$crop, border='red', col='#0000FF10', add=TRUE)
+	
+	xTcrop = wrapPoly(x=wrld_simpl, crs=myCrsMoll)
+	DcountryT  = grep(country, xTcrop$NAME)
+	
+	map.new(xTcrop)
+	plot(attributes(myCrsMoll)$ellipse, add=TRUE, col='lightBlue', border='blue')
+	plot(xTcrop,add=TRUE, col='grey')
+	plot(xTcrop[DcountryT,], col='green', add=TRUE)
+	
+	gridlinesWrap(crs=xTcrop, lty=2, col='red')
+	
+	
 }
 #'
\ No newline at end of file
